/**
 * This is the base error class for any error that may be raised by our API.
 */
export default class ResponseError extends Error {
    readonly status: number;
    readonly code: string;
    readonly title: string;
    /**
     * Other metadata specific for the error.
     */
    readonly meta: any[];
    /**
     * Creates a new response error.
     * @param status The HTTP status code, e.g. 400/500.
     * @param code The error code, e.g. 'pageNotFound'.
     * @param title A translatable error message.
     * @param meta Other metadata that depends on the error code.
     */
    constructor(status: number, code: string, title: string, ...meta: any[]);
}
