"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * This is the base error class for any error that may be raised by our API.
 */
class ResponseError extends Error {
    /**
     * Creates a new response error.
     * @param status The HTTP status code, e.g. 400/500.
     * @param code The error code, e.g. 'pageNotFound'.
     * @param title A translatable error message.
     * @param meta Other metadata that depends on the error code.
     */
    constructor(status, code, title, ...meta) {
        super(`Error ${code}: ${title} ` + JSON.stringify({ meta }));
        this.status = status;
        this.code = code;
        this.title = title;
        this.meta = meta;
    }
}
exports.default = ResponseError;
//# sourceMappingURL=response-error.js.map