"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
/**
 * A field containing a javascript Date object.
 */
class DateField extends __1.Field {
    constructor(description) {
        super(description);
    }
    /**
     * Creates a new date field.
     * @param description The description of the field.
     * @return The created field.
     */
    static create(description) {
        return new DateField(description);
    }
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type, but it should not be null.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key, value) {
        if (typeof value === 'string') {
            const timestamp = Date.parse(value);
            if (!timestamp) {
                throw __1.invalidFormat(key, value, 'ISO 8601');
            }
            value = new Date(timestamp);
        }
        if (value instanceof Date) {
            return value;
        }
        throw __1.invalidType(key, value);
    }
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key, value) {
        return value;
    }
}
exports.default = DateField;
//# sourceMappingURL=date-field.js.map