import { Field, Model, ModelConstructor, ModelProperties } from '..';
/**
 * Creates a field that references another model.
 */
export default class EmbeddedField<TModel extends Model> extends Field<ModelProperties, TModel> {
    private model;
    protected constructor(model: ModelConstructor<TModel>, description: string);
    /**
     * Creates a new embedded field.
     * @param constructor The constructor of the model that will be referenced.
     * @param description The description of the field.
     * @return The created field.
     */
    static of<T extends Model>(constructor: ModelConstructor<T>, description: string): EmbeddedField<T>;
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key: string, value: ModelProperties | TModel): TModel;
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key: string, value: TModel): ModelProperties;
}
