"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
/**
 * Creates a field that references another model.
 */
class EmbeddedField extends __1.Field {
    constructor(model, description) {
        super(description);
        this.model = model;
    }
    /**
     * Creates a new embedded field.
     * @param constructor The constructor of the model that will be referenced.
     * @param description The description of the field.
     * @return The created field.
     */
    static of(constructor, description) {
        return new EmbeddedField(constructor, description);
    }
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key, value) {
        if (value.constructor === this.model) {
            return value;
        }
        if (value.constructor === Object) {
            return new this.model(value);
        }
        throw __1.invalidType(key, value);
    }
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key, value) {
        return value.serialize();
    }
}
exports.default = EmbeddedField;
//# sourceMappingURL=embedded-field.js.map