import { Field } from '..';
export declare type EnumValue = string | number | symbol;
/**
 * Class responsible for validating enum fields.
 * @typeparam T The type of the enum.
 * @typeparam K The type of the enum keys.
 * @typeparam V The type of the enum values.
 */
export default class EnumField<T extends {
    [P in keyof T]: V;
}, K extends keyof T, V extends EnumValue> extends Field<K, V> {
    private enumType;
    /** A mapping of the enum values to their respective keys. */
    private readonly valueToKey;
    private constructor();
    /**
     * Creates a new enum field for the given enum type.
     * @param enumType The type of the enum.
     * @param description The description of the field.
     * @typeparam T The type of the enum.
     * @typeparam K The type of the enum keys.
     * @typeparam V The type of the enum values.
     * @return The created field.
     */
    static of<T extends {
        [P in keyof T]: V;
    }, K extends keyof T, V extends EnumValue>(enumType: T, description: string): EnumField<T, K, string | number | symbol>;
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type, but it should not be null.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key: string, value: K | V): V;
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key: string, value: V): K;
}
