"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Defines an interface for all schema fields.
 */
const __1 = require("..");
/**
 * The base class for all fields.
 * @typeparam TExternal The type used when the field is serialized.
 * @typeparam TInternal The type used when the field is used internally (it must match the class property).
 */
class Field {
    /**
     * Creates a new field.
     * @param descriptionText The description of the field.
     * @param options Settings for the field.
     */
    constructor(descriptionText, options = {}) {
        this.descriptionText = descriptionText;
        this.options = options;
    }
    /**
     * Gets the description of the field.
     */
    get description() {
        return this.descriptionText;
    }
    /**
     * Marks this field as required.
     * @return this
     */
    asRequired() {
        this.options.required = true;
        return this;
    }
    /**
     * Gets the value of the field or its default value. This raises an error if the field is required and has no value yet.
     * @param key The attribute name of the field in the model.
     * @param value The value of the field.
     * @return The parsed value.
     */
    get(key, value) {
        const { required } = this.options;
        if (required && value == null) {
            throw __1.fieldRequired(key);
        }
        return value === undefined ? null : value;
    }
}
exports.default = Field;
//# sourceMappingURL=field.js.map