import { Field } from '..';
export default class ListField<TExternal, TInternal = TExternal> extends Field<TExternal[], TInternal[]> {
    private items;
    protected constructor(items: Field<TExternal, TInternal>, description: string);
    /**
     * Creates a new list field.
     * @param field The field schema of each of the items.
     * @return The created field.
     */
    static of<TExternal, TInternal>(field: Field<TExternal, TInternal>): ListField<TExternal, TInternal>;
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type, but it should not be null.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key: string, value: (TExternal | TInternal)[] | null): TInternal[];
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key: string, value: TInternal[]): TExternal[];
}
