"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
class ListField extends __1.Field {
    constructor(items, description) {
        super(description);
        this.items = items;
    }
    /**
     * Creates a new list field.
     * @param field The field schema of each of the items.
     * @return The created field.
     */
    static of(field) {
        return new ListField(field.asRequired(), field.description);
    }
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type, but it should not be null.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key, value) {
        if (Array.isArray(value)) {
            return value.map((item, index) => this.items.set(`${key}[${index}]`, item));
        }
        throw __1.invalidType(key, value);
    }
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key, value) {
        return value.map((item, index) => this.items.serialize(`${key}[${index}]`, item));
    }
}
exports.default = ListField;
//# sourceMappingURL=list-field.js.map