import { Field } from '..';
export default class StringField extends Field<string> {
    private regex;
    /**
     * Creates a new string field.
     * @param description The description of the field.
     * @param regex An optional regex to validate the field with.
     */
    protected constructor(description: string, regex?: RegExp);
    /**
     * Creates a new string field.
     * @param description The description of the field.
     * @return The created field.
     */
    static create(description: string): StringField;
    /**
     * Adds a regex validation to the string field.
     * @param regex The regex to validate the field with.
     * @return this
     */
    withRegex(regex: RegExp): this;
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type, but it should not be null.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key: string, value: any): string;
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key: string, value: string): string;
}
