/**
 * Creates a field that can contains any of two types of field.
 */
import { Field } from '..';
export default class UnionField<TExternal1, TExternal2, TInternal1, TInternal2> extends Field<TExternal1 | TExternal2, TInternal1 | TInternal2> {
    private fields;
    protected constructor(fields: [Field<TExternal1, TInternal1>, Field<TExternal2, TInternal2>], description: string);
    /**
     * Creates a new embedded field.
     * @param field1 The first field that is allowed.
     * @param field2 The second fields that is allowed.
     * @param description The description of the field.
     * @return The created field.
     */
    static of<TExternal1, TExternal2, TInternal1, TInternal2>(field1: Field<TExternal1, TInternal1>, field2: Field<TExternal2, TInternal2>, description?: string): UnionField<TExternal1, TExternal2, TInternal1, TInternal2>;
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key: string, value: TExternal1 | TExternal2 | TInternal1 | TInternal2): TInternal1 | TInternal2;
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key: string, value: TInternal1 | TInternal2): TExternal1 | TExternal2;
}
