"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Creates a field that can contains any of two types of field.
 */
const __1 = require("..");
class UnionField extends __1.Field {
    constructor(fields, description) {
        super(description);
        this.fields = fields;
    }
    /**
     * Creates a new embedded field.
     * @param field1 The first field that is allowed.
     * @param field2 The second fields that is allowed.
     * @param description The description of the field.
     * @return The created field.
     */
    static of(field1, field2, description) {
        description = description || `Either ${field1.description.toLocaleLowerCase()} or ${field2.description.toLocaleLowerCase()}`;
        return new UnionField([field1, field2], description);
    }
    /**
     * Parses and validates the given value, throwing an error if the value is invalid.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse. It may be either the internal or the external type.
     * @return The parsed value.
     * @throws ValidationError
     */
    set(key, value) {
        const [field1, field2] = this.fields;
        try {
            const value1 = value;
            return field1.set(key, value1);
        }
        catch (e) {
            const value2 = value;
            return field2.set(key, value2);
        }
    }
    /**
     * Converts the value from the internal format to the external format.
     * @param key The attribute name of the field in the model.
     * @param value The value to parse.
     * @return The parsed value.
     * @throws ValidationError
     */
    serialize(key, value) {
        const [field1, field2] = this.fields;
        try {
            // by calling set we validate that the field value is a valid TInternal1
            return field1.serialize(key, field1.set(key, value));
        }
        catch (e) {
            return field2.serialize(key, value);
        }
    }
}
exports.default = UnionField;
//# sourceMappingURL=union-field.js.map