import { Mapping, Field } from '..';
export interface ModelProperties extends Mapping<any> {
}
export declare type ModelConstructor<T extends Model> = new (properties?: ModelProperties) => T;
/**
 * Models are responsible for defining their own fields.
 */
export default abstract class Model {
    /** The fields of the model (part of the class prototype) */
    private $fields;
    /** The data of the model */
    private readonly $data;
    protected constructor();
    /**
     * Adds a new field to the class.
     * @param key The key of the field.
     * @param field The field.
     */
    addField<TExternal, TInternal>(key: string, field: Field<TExternal, TInternal>): void;
    /**
     * Defines the properties based on the fields of the class.
     */
    defineProperties(): void;
    /**
     * Populates this model with all the given properties. Non-existent fields are ignored.
     * @param properties The properties to set.
     * @return this.
     */
    populate(properties?: ModelProperties): this;
    /**
     * Validates the schema. Override this method to add extra validations.
     * @return this.
     */
    validate(): this;
    /**
     * Validates the schema and serializes it to the output format.
     * @return The serialized properties.
     */
    serialize(): ModelProperties;
}
